source("irrfahrt.r")

#====================================================================
# Diskrete Irrfahrt mit absorbierenden Schranken
#====================================================================

# Spielverlauf simulieren b)
#===========================

# k= 5 und M = 10
k <- 5
M <- 10
opar <- par(mfrow = c(2, 2))
schrankenIrrfahrt(p = 0.5, q = 0.5, a = (-1 * k), b = (M - k), n = 50)
schrankenIrrfahrt(p = 0.5, q = 0.5, a = (-1 * k), b = (M - k), n = 50)
schrankenIrrfahrt(p = 0.7, q = 0.3, a = (-1 * k), b = (M - k), n = 50)
schrankenIrrfahrt(p = 0.3, q = 0.7, a = (-1 * k), b = (M - k), n = 50)

# k= 200 und M = 500
k <- 200
M <- 500
par(mfrow = c(1, 2))
schrankenIrrfahrt(p = 0.7, q = 0.3, a = (-1 * k), b = (M - k), n = 1000)
schrankenIrrfahrt(p = 0.3, q = 0.7, a = (-1 * k), b = (M - k), n = 1000)

# k= 200 und M = 500 aber p in {0.49, 0.5, 0.51}
par(mfrow = c(2, 2))
schrankenIrrfahrt(p = 0.49, q = 0.51, a = (-1 * k), b = (M - k), n = 1000)
schrankenIrrfahrt(p = 0.51, q = 0.49, a = (-1 * k), b = (M - k), n = 1000)
schrankenIrrfahrt(p = 0.50, q = 0.50, a = (-1 * k), b = (M - k), n = 1000)
plot.new()

par(opar)

# Gewinnwahrscheinlichkeit ausrechnen P_k d)
#===========================================

#------------------
# Input-Parameter:
#
# p            Wahrscheinlichkeiten fuer Gewinn
# k            Startkapital Fahrradfan
# M            Startkapital Haendler

#------------------
# Output:
# Vektor mit Gewinnwahrscheinlichkeiten fuer vektorielles p

Pk <- function(p, k, M) {
	ifelse((p == 0.5), rep(k/m, length(p)), (1-((1-p)/p)^k)/(1-((1-p)/p)^M))
}

p <- seq(from = 0, to = 1, length = 1000)

par(lab=c(11,11,7), las=1)

# k = 5 und M = 10
plot(p, Pk(p, k = 5, M = 10), type = "l", ylab = expression(P[k]), lwd = 2)
lines(c(-1, 0.5), c(0.5, 0.5), lty = 2 , lwd = 2)
lines(c(0.5, 0.5), c(-1, 0.5), lty = 2 , lwd = 2)

# k = 7 und M = 10
lines(p, Pk(p, k = 7, M = 10), col = 2, lwd = 2)
lines(c(0.5, 0.5), c(0.5, 0.7), col = 2, lty = 2 , lwd = 2)
lines(c(-1, 0.5), c(0.7, 0.7), col = 2, lty = 2 , lwd = 2)

# k = 50 und M = 100
lines(p, Pk(p, k = 50, M = 100), col = 3, lwd = 2)

legend("topleft", c("k = 7   M = 10", "k = 5   M = 10", "k = 50  M = 100"),
col = c(2, 1, 3), lwd = 2, bg = "white")
























